import pygame as pg
from pygame.locals import *
import random
import sys

# color
BLACK = (0, 0, 0)
WHITE = (255, 255, 255)
RED = (255, 0, 0)

# game settings
WINDOW_WIDTH = 500
WINDOW_HEIGHT = 400
FPS = 30
pg.init()
screen = pg.display.set_mode((WINDOW_WIDTH, WINDOW_HEIGHT))
pg.display.set_caption("Rock Paper Scissors")

# load the images
rps_intro = pg.image.load("rps-intro.png")
rock_img = pg.image.load("rock.png")
paper_img = pg.image.load("paper.png")
scissors_img = pg.image.load("scissors.png")

# resize images
rps_intro = pg.transform.scale(rps_intro, (WINDOW_WIDTH, WINDOW_HEIGHT))
rock_img = pg.transform.scale(rock_img, (100, 100))
paper_img = pg.transform.scale(paper_img, (100, 100))
scissors_img = pg.transform.scale(scissors_img, (100, 100))

def game_intro():
    screen.blit(rps_intro, (0, 0))
    pg.display.update()
    pg.time.wait(1000)

game_intro()

def draw_structure():
    screen.fill(WHITE)
    screen.blit(rock_img, (50, 100))
    screen.blit(paper_img, (200, 100))
    screen.blit(scissors_img, (350, 100))

    # create game header
    pg.draw.rect(screen, BLACK, (0, 0, WINDOW_WIDTH, 50))
    header_text = pg.font.Font(None, 36).render("Rock Paper Scissors", True, WHITE)
    screen.blit(header_text, (WINDOW_WIDTH // 2 - header_text.get_width() // 2, 15))
    instruction = pg.font.Font(None, 30).render("Click on the rock, paper or scissors to play!",True, BLACK)
    screen.blit(instruction, (WINDOW_WIDTH // 2 - instruction.get_width() // 2, 60))
    pg.display.update()

draw_structure()

def handle_click(x, y):
    if x > 50 and x < 150 and y > 100 and y < 200:
        display_choice("rock")
        return
    elif x > 200 and x < 300 and y > 100 and y < 200:
        display_choice("paper")
        return
    elif x > 350 and x < 450 and y > 100 and y < 200:
        display_choice("scissors")
        return
    else:
        return

def display_choice(player_choice):
    playmode_font = pg.font.Font(None, 25)
    # display player choice
    player_choice_text = playmode_font.render("You chose: " + player_choice, True, BLACK)
    screen.blit(player_choice_text, (10, 220))

    # display computer choice
    computer_choice = random.choice(["rock", "paper", "scissors"])
    computer_choice_text = playmode_font.render("Computer chose: " + computer_choice, True, BLACK)
    screen.blit(computer_choice_text, (200, 220))

    check_winner(player_choice, computer_choice)

    pg.display.update()

def check_winner(player_choice, computer_choice):
    if player_choice == computer_choice:
        game_status = "It's a tie!"
    elif player_choice == "rock":
        if computer_choice == "paper":
            game_status = "You lose! Paper covers rock."
        else:
            game_status = "You win! Rock breaks scissors."
    elif player_choice == "paper":
        if computer_choice == "scissors":
            game_status = "You lose! Scissors cut paper."
        else:
            game_status = "You win! Paper covers rock."
    elif player_choice == "scissors":
        if computer_choice == "rock":
            game_status = "You lose! Rock breaks scissors."
        else:
            game_status = "You win! Scissors cut paper."
    else:
        print("Invalid choice!")
    screen.blit(pg.font.Font(None, 40).render(game_status, True, RED), (10, 275))
    
    # show reset button
    reset_button = pg.Rect(150, 320, 200, 50)
    pg.draw.rect(screen, (173, 89, 29), reset_button)
    reset_text = pg.font.Font(None, 30).render("Replay", True, WHITE)
    screen.blit(reset_text, (WINDOW_WIDTH // 2 - reset_text.get_width() // 2, 335))

# main game loop
while True:
    for event in pg.event.get():
        if event.type == pg.QUIT:
            pg.quit()
            sys.exit()
        elif event.type == pg.MOUSEBUTTONDOWN:
            mouse_x, mouse_y = pg.mouse.get_pos()
            handle_click(mouse_x, mouse_y)

            # reset game
            if mouse_x > 150 and mouse_x < 350 and mouse_y > 320 and mouse_y < 370:
                draw_structure()
    pg.time.Clock().tick(FPS)
